@@ -3,16 +3,17 @@ OC.L10N.register(
     {
     "Details" : "Detallar",
     "Contacts" : "Əlaqələr",
-    "Send email" : "Email yolla",
-    "Download" : "Yüklə",
     "Rename" : "Adı dəyiş",
-    "Enabled" : "İşə salınıb",
+    "Send email" : "Email yolla",
     "Delete" : "Sil",
     "Copy link" : "linki nüsxələ",
+    "Download" : "Yüklə",
     "can edit" : "dəyişmək olar",
+    "Add" : "Əlavə etmək",
     "Password protection" : "Password protection",
     "Save" : "Saxla",
     "Description" : "Açıqlanma",
+    "Settings" : "Settings",
     "Cancel" : "Dayandır",
     "Invalid image" : "Yalnış şəkil",
     "Name" : "Ad",
@@ -27,13 +28,23 @@ OC.L10N.register(
     "Email" : "Email",
     "Admin" : "İnzibatçı",
     "Owner" : "Owner",
-    "Users" : "İstifadəçilər",
+    "Prefix" : "Prefiks",
+    "Suffix" : "Suffiks",
+    "Nickname" : "Ləqəb",
     "Notes" : "Qeydlər",
+    "Website" : "Veb sayt",
     "Location" : "Yerləşdiyiniz ünvan",
     "Home" : "Ev",
     "Work" : "İş",
     "Other" : "Digər",
     "Address" : "Ünvan",
-    "Birthday" : "Ad günü"
+    "City" : "Şəhər",
+    "Country" : "Ölkə",
+    "Birthday" : "Ad günü",
+    "Anniversary" : "Yubiley",
+    "Phone" : "Telefon",
+    "Mobile" : "Mobil",
+    "Fax" : "Faks",
+    "Pager" : "Peycer"
 },
 "nplurals=2; plural=(n != 1);");
